@@ -1,9 +1,9 @@
 /*****************************************************************************
- * RRDtool 1.4.4  Copyright by Tobi Oetiker, 1997-2010
+ * RRDtool 1.4.6  Copyright by Tobi Oetiker, 1997-2012
  *****************************************************************************
  * rrd_format.c  RRD Database Format helper functions
  *****************************************************************************
- * $Id: rrd_format.c 2106 2010-07-05 15:38:22Z oetiker $
+ * $Id: rrd_format.c 2255 2012-01-16 14:40:06Z oetiker $
  * $Log$
  * Revision 1.5  2004/05/18 18:53:03  oetiker
  * big spell checking patch -- slif@bellsouth.net
@@ -48,6 +48,9 @@
  *
  *****************************************************************************/
 #include "rrd_tool.h"
+#ifdef WIN32
+#include "stdlib.h"
+#endif
 
 #define converter(VV,VVV) \
    if (strcmp(#VV, string) == 0) return VVV;
@@ -105,8 +108,7 @@ off_t rrd_get_header_size(
     return sizeof(stat_head_t) + \
         sizeof(ds_def_t) * rrd->stat_head->ds_cnt + \
         sizeof(rra_def_t) * rrd->stat_head->rra_cnt + \
-        sizeof(time_t) + \
-        sizeof(live_head_t) + \
+        ( atoi(rrd->stat_head->version) < 3 ? sizeof(time_t) : sizeof(live_head_t) ) + \
         sizeof(pdp_prep_t) * rrd->stat_head->ds_cnt + \
         sizeof(cdp_prep_t) * rrd->stat_head->ds_cnt * rrd->stat_head->rra_cnt + \
         sizeof(rra_ptr_t) * rrd->stat_head->rra_cnt;
