@@ -1,5 +1,5 @@
 /****************************************************************************
- * RRDtool 1.4.4  Copyright by Tobi Oetiker, 1997-2010
+ * RRDtool 1.4.6  Copyright by Tobi Oetiker, 1997-2012
  ****************************************************************************
  * rrd_xport.c  export RRD data 
  ****************************************************************************/
@@ -65,6 +65,7 @@ int rrd_xport(
         {"maxrows", required_argument, 0, 'm'},
         {"step", required_argument, 0, 261},
         {"enumds", no_argument, 0, 262},    /* these are handled in the frontend ... */
+        {"json", no_argument, 0, 263},    /* these are handled in the frontend ... */
         {"daemon", required_argument, 0, 'd'},
         {0, 0, 0, 0}
     };
@@ -263,6 +264,7 @@ int rrd_xport_fn(
                 while (--j > -1)
                     free(legend_list[j]);
                 free(legend_list);
+                free(step_list);
                 rrd_set_error("malloc xport legend entry");
                 return (-1);
             }
